@@ -18,7 +18,7 @@ from cvehound.util import get_spatch_version, get_rule_cves, get_cves_metadata
 from cvehound.kbuild import KbuildParser
 from cvehound.config import Config
 
-__VERSION__ = '1.0.7'
+__VERSION__ = '1.0.8'
 
 
 class CVEhound:
@@ -100,7 +100,7 @@ class CVEhound:
         logging.info('https://www.linuxkernelcves.com/cves/' + cve)
 
     def _print_affected_files(self, config):
-        if config['files']:
+        if 'files' in config and config['files']:
             logging.info('Affected Files:')
             for file in config['files']:
                 logic = config['files'][file]['logic']
@@ -178,8 +178,8 @@ class CVEhound:
         if 'ERROR' not in output:
             return False
 
+        config_result = {}
         if self.config_map:
-            config_result = {}
             files = {}
             for line in output.split('\n'):
                 file = []
